@@ -427,7 +427,7 @@ int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask)
       sin_addr.s_addr;
     p1 = (unsigned char *) ip;
     p2 = (unsigned char *) netmask;
-    diag(COMPONENT,DIAG_DEBUG,"ip %d.%d.%d.%d mask %d.%d.%d.%d\n",
+    diag(COMPONENT,DIAG_DEBUG,"ip %d.%d.%d.%d mask %d.%d.%d.%d",
       p1[0],p1[1],p1[2],p1[3],p2[0],p2[1],p2[2],p2[3]);
     return 0;
 }
@@ -438,7 +438,7 @@ int get_local(int fd,struct sockaddr_atmsvc *addr)
     int length,result;
 
     length = sizeof(struct sockaddr_atmsvc);
-    result = getsockname(fd,addr,&length);
+    result = getsockname(fd,(struct sockaddr *) addr,&length);
     if (result < 0)
 	diag(COMPONENT,DIAG_ERROR,"getsockname: %s",strerror(errno));
     return result;
