@@ -69,8 +69,6 @@ static int try_pvc(const char *text,struct sockaddr_atmpvc *addr,int flags)
     addr->sap_addr.itf = part[0];
     addr->sap_addr.vpi = part[1];
     addr->sap_addr.vci = part[2];
-    memset(&addr->sap_txtp,0,sizeof(struct atm_trafprm)); /* paranoia */
-    memset(&addr->sap_rxtp,0,sizeof(struct atm_trafprm));
     return 0;
 }
 
