@@ -1,6 +1,6 @@
 /* qgen.h - constructor/parser generator for Q.2931-like data structures */
  
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
  
  
 #ifndef QGEN_H
@@ -33,6 +33,7 @@ typedef struct _field {
     int field; /* field number */
     int jump; /* move by that many bytes before writing that field */
     int group; /* group number, only in first element of group */
+    int seq; /* sequence number - for dumping */
     /* --- the following fields are initialized in the second phase */
     int has_required;
     /* --- the following fields are initialized in the third phase */
