@@ -22,7 +22,7 @@
 
 
 #define COMPONENT "SIGD"
-#define CONFIG_FILE "./atmsigd.conf"
+#define CONFIG_FILE "/etc/atmsigd.conf"
 
 
 extern int yyparse(void);
@@ -37,8 +37,8 @@ static SAAL_DSC saal;
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -n ] [ -N ]\n",
-      name);
+    fprintf(stderr,"usage: %s [ -b ] [ -c config_file ] [ -d ] [ -l logfile ] "
+      "[ -n ] [ -N ]\n",name);
     exit(1);
 }
 
@@ -212,22 +212,30 @@ static void setup_signals(void)
 
 int main(int argc,char **argv)
 {
+    const char *config_file;
     int c,background;
 
     set_application("atmsigd");
+    config_file = CONFIG_FILE;
     background = 0;
     memset(&signaling_pvc,0,sizeof(signaling_pvc));
     signaling_pvc.sap_addr.vci = 5;
-    while ((c = getopt(argc,argv,"bdnN")) != EOF)
+    while ((c = getopt(argc,argv,"bc:dl:nN")) != EOF)
 	switch (c) {
 	    case 'b':
 		background = 1;
 		break;
+	    case 'c':
+		config_file = optarg;
+		break;
 	    case 'd':
 		set_verbosity(NULL,DIAG_DEBUG);
 		debug = 1;
 		q_dump = 1;
 		break;
+	    case 'l':
+		set_logfile(optarg);
+		break;
 	    case 'n':
 		pretty = A2T_PRETTY;
 		break;
@@ -240,8 +248,8 @@ int main(int argc,char **argv)
     if (optind != argc) usage(argv[0]);
     diag(COMPONENT,DIAG_INFO,"Linux ATM signaling UNI 3.x(red)/AAL5, version "
       VERSION);
-    if (!(yyin = fopen(CONFIG_FILE,"r")))
-	diag(COMPONENT,DIAG_WARN,CONFIG_FILE " not found. - Using defaults.");
+    if (!(yyin = fopen(config_file,"r")))
+	diag(COMPONENT,DIAG_WARN,"%s not found. - Using defaults.",config_file);
     else if (yyparse()) {
 	    diag(COMPONENT,DIAG_FATAL,"Error in config file. - Aborting.");
 	    return 1;
