@@ -116,7 +116,8 @@ static void setup_call(unsigned long call_ref)
 }
 
 
-static void send_status(SOCKET *sock,unsigned char cause,...)
+static void send_status(SOCKET *sock,unsigned long call_ref,
+  unsigned char cause,...)
 {
     va_list ap;
     Q_DSC dsc;
@@ -133,8 +134,8 @@ static void send_status(SOCKET *sock,unsigned char cause,...)
 	}
     }
     else {
-	q_assign(&dsc,QF_call_ref,0);
-	q_assign(&dsc,QF_call_state,0); /* REST 0 - Null */
+	q_assign(&dsc,QF_call_ref,call_ref);
+	q_assign(&dsc,QF_call_state,0); /* U0 - Null / REST 0 - Null */
     }
     q_assign(&dsc,QF_cause,cause);
     va_start(ap,cause);
@@ -153,6 +154,7 @@ static void send_status(SOCKET *sock,unsigned char cause,...)
 		break;
 	    }
 	default:
+	    ;
     }
     va_end(ap);
     if ((size = q_close(&dsc)) >= 0) to_signaling(q_buffer,size);
@@ -236,16 +238,13 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 		      qs_name[state],qs_name[sock->q2931_state]);
 	    }
 	    return;
-	case QMSG_STATUS_ENQ:
-	    send_status(sock,ATM_CV_RESP_STAT_ENQ);
-	    return;
 	default:
 	    ;
     }
     switch (mid) {
 	case QMSG_CALL_PROC: /* CONNECTING, WAIT_REL, REL_REQ */
 	    if (sock->state == ss_wait_rel || sock->state == ss_rel_req) {
-		send_status(sock,ATM_CV_INCOMP_MSG,QMSG_CALL_PROC);
+		send_status(sock,0,ATM_CV_INCOMP_MSG,QMSG_CALL_PROC);
 		return;
 	    }
 	    if (sock->state != ss_connecting) break;
@@ -267,7 +266,7 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 	    return;
 	case QMSG_CONNECT: /* CONNECTING, REL_REQ */
 	    if (sock->state == ss_rel_req) {
-		send_status(sock,ATM_CV_INCOMP_MSG,QMSG_CONNECT);
+		send_status(sock,0,ATM_CV_INCOMP_MSG,QMSG_CONNECT);
 		return;
 	    }
 	    if (sock->state != ss_connecting) break;
@@ -306,7 +305,7 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 	    diag(COMPONENT,DIAG_DEBUG,"CA vpi.vci=%d.%d",
 	      sock->pvc.sap_addr.vpi,sock->pvc.sap_addr.vci);
 	    if (sock->state == ss_wait_rel || sock->state == ss_rel_req) {
-		send_status(sock,ATM_CV_INCOMP_MSG,QMSG_CONN_ACK);
+		send_status(sock,0,ATM_CV_INCOMP_MSG,QMSG_CONN_ACK);
 		return;
 	    }
 	    if (sock->state != ss_accepting) break;
@@ -399,7 +398,8 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 		    case ss_connected:
 			diag(COMPONENT,DIAG_INFO,"Passive close (CR 0x%06X)",
 			  sock->call_ref);
-			sock->error = -sock->error; /* context is still around */
+			sock->error = -sock->error;
+			    /* context is still around */
 			send_close(sock);
 			/* fall through */
 		    case ss_hold:
@@ -415,14 +415,14 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 	    }
 	default:
 	    diag(COMPONENT,DIAG_WARN,"Bad Q.2931 message %d",mid);
-	    send_status(sock,ATM_CV_UNKNOWN_MSG_TYPE,mid);
+	    send_status(sock,0,ATM_CV_UNKNOWN_MSG_TYPE,mid);
 	    return;
     }
     diag(COMPONENT,DIAG_WARN,
       "Q.2931 message %s is incompatible with state %s/%s (%d?%d)",
       mid2name(mid),state_name[sock->state],qs_name[sock->q2931_state],
       (int) sock->state,(int) sock->q2931_state);
-    send_status(sock,ATM_CV_INCOMP_MSG,mid);
+    send_status(sock,0,ATM_CV_INCOMP_MSG,mid);
 }
 
 
@@ -489,7 +489,7 @@ static void process_q2931(void *msg)
 		    int vpi,vci;
 
 		    if (!q_present(&in_dsc,QG_conn_id)) {
-			send_status(NULL,ATM_CV_MAND_IE_MISSING,
+			send_status(NULL,0L,ATM_CV_MAND_IE_MISSING,
 			  ATM_IE_CONN_ID);
 			return;
 		    }
@@ -499,7 +499,7 @@ static void process_q2931(void *msg)
 			if (curr->pvc.sap_addr.vpi == vpi &&
 			  curr->pvc.sap_addr.vci == vci) break;
 		    if (!curr) {
-			send_status(NULL,ATM_CV_INVALID_IE,
+			send_status(NULL,0L,ATM_CV_INVALID_IE,
 			  ATM_IE_CONN_ID);
 			return;
 		    }
@@ -512,7 +512,7 @@ static void process_q2931(void *msg)
 		send_restart_ack(0,0);
 		break;
 	    default:
-		send_status(NULL,ATM_CV_INVALID_IE,ATM_IE_RESTART);
+		send_status(NULL,0L,ATM_CV_INVALID_IE,ATM_IE_RESTART);
 	}
 	return;
     }
@@ -528,6 +528,10 @@ static void process_q2931(void *msg)
 	if (!curr) setup_call(call_ref);
 	return;
     }
+    if (mid == QMSG_STATUS_ENQ) {
+	send_status(curr,call_ref,ATM_CV_RESP_STAT_ENQ);
+	return;
+    }
     if (curr && q_present(&in_dsc,QF_ep_ref) && mid != QMSG_ADD_PARTY &&
       mid != QMSG_DROP_PARTY_ACK)
 	if (curr->ep_ref != q_fetch(&in_dsc,QF_ep_ref)) {
@@ -536,10 +540,10 @@ static void process_q2931(void *msg)
 	    return;
 	}
     if (!curr || curr->q2931_state == qs_null) {
-	if (mid == QMSG_REL_COMP)
-	    send_release_complete(call_ref,ATM_CV_INV_CR);
-	else if (mid != QMSG_STATUS)
-		if (q_fetch(&in_dsc,QF_call_state) != (int) qs_null)
+	if (mid != QMSG_REL_COMP)
+	    if (mid != QMSG_STATUS)
+		send_release_complete(call_ref,ATM_CV_INV_CR);
+	    else if (q_fetch(&in_dsc,QF_call_state) != (int) qs_null)
 		    send_release_complete(call_ref,ATM_CV_INCOMP_MSG);
 	return;
     }
