@@ -11,30 +11,34 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <linux/atm.h>
+#include <atm.h>
 
 
 #define BSIZE 8192
 
 
+static void usage(const char *name)
+{
+    fprintf(stderr,"usage: %s [itf.]vpi.vci\n",name);
+    exit(1);
+}
+
+
 int main(int argc,char **argv)
 {
     struct sockaddr_atmpvc addr;
     int s;
 
-    if (argc != 4) {
-	fprintf(stderr,"usage: %s itf vpi vci\n",argv[0]);
-	return 1;
-    }
+    if (argc != 2) usage(argv[0]);
     if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL5)) < 0) {
 	perror("socket");
 	return 1;
     }
     memset(&addr,0,sizeof(addr));
-    addr.sap_family = AF_ATMPVC;
-    addr.sap_addr.itf = atoi(argv[1]);
-    addr.sap_addr.vpi = atoi(argv[2]);
-    addr.sap_addr.vci = atoi(argv[3]);
+    if (text2atm(argv[1],(struct sockaddr *) &addr,sizeof(addr),T2A_PVC) < 0)
+	usage(argv[0]);
     addr.sap_rxtp.class = ATM_UBR;
+    addr.sap_rxtp.max_sdu = BSIZE;
     if (bind(s,(struct sockaddr *) &addr,sizeof(addr)) < 0) {
 	perror("bind");
 	return 1;
