@@ -76,6 +76,7 @@ struct sockaddr_in sinme;
 struct sockaddr_in sinhim;
 struct sockaddr_in frominet;
 struct sockaddr_atmsvc satm;
+struct atm_qos qos;
 
 int domain, fromlen;
 int fd;				/* fd of network socket */
@@ -264,28 +265,14 @@ int no_check = 0;
 		fprintf(stderr,"invalid ATM address (PVC or SVC expected)\n");
 		exit(1);
 	    }
-
-#define INIT(type,fld) \
-	if (!trans) ((type *) &satm)->fld##_rxtp.class = ATM_UBR; \
-	else if (!pcr) ((type *) &satm)->fld##_txtp.class = ATM_UBR; \
-	    else { \
-		    ((type *) &satm)->fld##_txtp.class = ATM_CBR; \
-		    ((type *) &satm)->fld##_txtp.max_pcr = pcr; \
-	    } \
-	((type *) &satm)->fld##_rxtp.max_sdu = \
-	  ((type *) &satm)->fld##_txtp.max_sdu = buflen
-
-	switch (satm.sas_family) {
-	    case AF_ATMPVC:
-		INIT(struct sockaddr_atmpvc,sap);
-		break;
-	    case AF_ATMSVC:
-		INIT(struct sockaddr_atmsvc,sas);
-		break;
-	    default:
-		fprintf(stderr,"bad AF %d\n",satm.sas_family);
-		exit(1);
-	}
+	memset(&qos,0,sizeof(qos));
+	if (!trans) qos.rxtp.class = ATM_UBR;
+	else if (!pcr) qos.txtp.class = ATM_UBR;
+	    else {
+		qos.txtp.class = ATM_CBR;
+		qos.txtp.max_pcr = pcr;
+	    }
+	qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
     }
     else
     if (trans)  {
@@ -355,8 +342,12 @@ int no_check = 0;
         udp?SOCK_DGRAM:SOCK_STREAM, atm ? ATM_AAL5 : 0)) < 0) err("socket");
     
     mes("socket");
-	if (!atm)
-	    if (setsockopt(fd, SOL_SOCKET, SO_NO_CHECK, &no_check, sizeof(long)) <
+	if (atm) {
+	    if (setsockopt(fd,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
+		err("setsockopt SO_ATMQOS");
+	    }
+	}
+	else if (setsockopt(fd, SOL_SOCKET, SO_NO_CHECK, &no_check, sizeof(long)) <
 		0) err("setsockopt: no_check");
     /* set socket buffer size */
 #if defined(SO_SNDBUF) || defined(SO_RCVBUF)
